Annotation Type DbUnitConnection


@Retention(RUNTIME) @Inherited @Documented @Target(TYPE) public @interface DbUnitConnection
Set the DBUnit connection configuration.
  • Required Element Summary

    Required Elements
    Modifier and Type
    Required Element
    Description
    Get JDBC password.
    Get JDBC Connection URL.
    Get JDBC user name.
  • Optional Element Summary

    Optional Elements
    Modifier and Type
    Optional Element
    Description
    Database driver to use: default is the empty string and the driver will automatically be selected, based on the connection URL.
  • Element Details

    • driver

      String driver
      Database driver to use: default is the empty string and the driver will automatically be selected, based on the connection URL.
      Returns:
      Database driver.
      Default:
      ""
    • url

      String url
      Get JDBC Connection URL.
      Returns:
      Connection URL.
    • user

      String user
      Get JDBC user name.
      Returns:
      User.
    • password

      String password
      Get JDBC password.
      Returns:
      Password.