Package com.github.mjeanroy.dbunit.core.annotations
package com.github.mjeanroy.dbunit.core.annotations
-
ClassDescriptionAnnotation that can be used to customize DBUnit configuration property when the DbUnit connection will be created.Implementation of
IDataTypeFactorythat should not be used publicly and where all methods will throwUnsupportedOperationException.Set the DBUnit connection configuration.Data set annotation used to specify which DbUnit dataset(s) should be loaded before executing a test.DbUnit initialization: allow user to run SQL scripts before loading DbUnit data set.DbUnit liquibase integration: allow test to initialize database with liquibase and load DbUnit data set next.Annotation that define the list ofReplacementsto use during test suite.Database operation to execute before test is executed.Database operation to execute after test is executed.Specify DBUnit test using: All dataset files located in:/datasetDefault setup operation:DbUnitOperation.CLEAN_INSERT. Default teardown operation:DbUnitOperation.TRUNCATE_TABLE. Default value replacers (NullValueReplacementsProvider,NowValueReplacementsProvider,CurrentTimestampValueReplacementsProviderandCurrentTimeValueReplacementsProvider).