Class DataSetBuilderRow
java.lang.Object
com.github.mjeanroy.dbunit.core.dataset.DataSetBuilderRow
Immutable representation of a single row in a dataset table.
Each column name appears at most once.
-
Method Summary
Modifier and TypeMethodDescriptionbooleangetBigDecimal(String columnName) Returns theBigDecimalvalue associated with the specified column.getBigInteger(String columnName) Returns theBigIntegervalue associated with the specified column.getBoolean(String columnName) Returns theBooleanvalue associated with the specified column.Get all column names in this row.Returns theDatevalue associated with the specified column.Returns theDoublevalue associated with the specified column.Returns theFloatvalue associated with the specified column.getInteger(String columnName) Returns theIntegervalue associated with the specified column.getLocalDate(String columnName) Returns theLocalDatevalue associated with the specified column.getLocalDateTime(String columnName) Returns theLocalDateTimevalue associated with the specified column.Returns theLongvalue associated with the specified column.getOffsetDateTime(String columnName) Returns theOffsetDateTimevalue associated with the specified column.Returns theShortvalue associated with the specified column.Returns theStringvalue associated with the specified column.Returns theUUIDvalue associated with the specified column.getZonedDateTime(String columnName) Returns theZonedDateTimevalue associated with the specified column.inthashCode()toString()
-
Method Details
-
getShort
Returns theShortvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aShort.
-
getInteger
Returns theIntegervalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aInteger.
-
getLong
Returns theLongvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aLong.
-
getFloat
Returns theFloatvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aFloat.
-
getDouble
Returns theDoublevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aDouble.
-
getBigInteger
Returns theBigIntegervalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aBigInteger.
-
getBigDecimal
Returns theBigDecimalvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aBigDecimal.
-
getBoolean
Returns theBooleanvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aBoolean.
-
getString
Returns theStringvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aString.
-
getDate
Returns theDatevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aDate.
-
getOffsetDateTime
Returns theOffsetDateTimevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aOffsetDateTime.
-
getLocalDateTime
Returns theLocalDateTimevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aLocalDateTime.
-
getZonedDateTime
Returns theZonedDateTimevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aZonedDateTime.
-
getLocalDate
Returns theLocalDatevalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aLocalDate.
-
getUUID
Returns theUUIDvalue associated with the specified column.- Parameters:
columnName- Name of the column.- Returns:
- Column value, or
nullif the column does not exist or has a null value. - Throws:
IllegalArgumentException- ifcolumnNameis blank.UnsupportedOperationException- If value cannot casted to aUUID.
-
getColumnNames
-
equals
-
hashCode
-
toString
-