Enum ResourceLoader

java.lang.Object
java.lang.Enum<ResourceLoader>
com.github.mjeanroy.dbunit.core.resources.ResourceLoader
All Implemented Interfaces:
Serializable, Comparable<ResourceLoader>, java.lang.constant.Constable

public enum ResourceLoader extends Enum<ResourceLoader>
Implementations of strategies to load resources.
  • Enum Constant Details

    • CLASSPATH

      public static final ResourceLoader CLASSPATH
      Load file from classpath.
    • FILE_SYSTEM

      public static final ResourceLoader FILE_SYSTEM
      Load file from file system.
    • URL

      public static final ResourceLoader URL
      Load file from HTTP url.
  • Method Details

    • values

      public static ResourceLoader[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ResourceLoader valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • load

      public Resource load(String name)
      Load given file path.
      Parameters:
      name - File path.
      Returns:
      Loaded file.
      Throws:
      DataSetLoaderException - If path cannot be loaded.
    • find

      public static ResourceLoader find(String value)
      Find loader according to given file pattern.
      Parameters:
      value - File pattern.
      Returns:
      Matched loader.