Class DbUnitException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.github.mjeanroy.dbunit.exception.DbUnitException
- All Implemented Interfaces:
Serializable
DbUnit exception.
This exception should be thrown by JUnit rule and DbUnit runner when initialization failed because of bad configuration.
This exception should be thrown by JUnit rule and DbUnit runner when initialization failed because of bad configuration.
- See Also:
-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
DbUnitException
-
DbUnitException
-