Package com.github.mjeanroy.dbunit.exception
package com.github.mjeanroy.dbunit.exception
-
Exception ClassesClassDescriptionWrap external parsing exception.Exception thrown when a class cannot be instantiated because of: Missing empty public constructor. The empty constructor is not public. Etc.Exception thrown when DataSet cannot be loaded.Exception thrown when DataSet cannot be parsed.DbUnit exception.Exception thrown when a field cannot be accessed.Wrap external SQL exception.Wrap external JSON parsing exception.Error thrown when an error occurred when dealing with resources.Error thrown when resource is not found.Error thrown when resource is not a valid resource.Exception thrown if an error occurred during SQL parsing.Wrap external YAML parsing exception.