All Classes and Interfaces
Class
Description
Abstract connection factory that can be used to automatically wrap exception.
Wrap external parsing exception.
Static Annotation Utilities.
Instance of
JdbcForeignKeyManager that will auto-detect the underlying implementation
to use based on the JDBC connection URL.Cache of values identified by a key.
Factory for
Cache instances.Cache loader: the role of a loader is to compute the value
to store in a cache.
Exception thrown when a class cannot be instantiated because of:
Missing empty public constructor.
The empty constructor is not public.
Etc.
Static Class Utilities.
A
ReplacementsProvider that will map following values to the current date:
current_timestamp
CURRENT_TIMESTAMP
current_timestamp()
CURRENT_TIMESTAMP()
A
ReplacementsProvider that will map following values to the current time (according to the system timezone):
current_time
CURRENT_TIME
current_time()
CURRENT_TIME()
Fluent builder for creating DbUnit
IDataSet instances
entirely in Java code.Annotate field that should be serialized as JSON when persisted to
the database using the
DataSetBuilder.Immutable representation of a single row in a dataset table.
Immutable value object representing a single column name and its value.
Immutable representation of a database table consisting of a name and an
ordered list of rows.
Factory to create instance of
IDataSet.Exception thrown when DataSet cannot be loaded.
Dataset parser: read file and returns in-memory dataset representation.
Exception thrown when DataSet cannot be parsed.
A provider of
IDataSet instances for DbUnit tests.An interceptor that can enable/disable the
"allowEmptyFields" feature of DbUnit.An interceptor that can enable/disable the
"batchedStatements" feature of DbUnit.An interceptor that can set the
"batchSize" property of DbUnit.An interceptor that can enable/disable the
"caseSensitiveTableNames" feature of DbUnit.Annotation that can be used to customize DBUnit configuration
property when the DbUnit connection will be created.
Implementation of
IDataTypeFactory that should not be used publicly
and where all methods will throw UnsupportedOperationException.An interceptor that can be used to apply some custom DbUnit configuration on a
DatabaseConfig instance.Set the DBUnit connection configuration.
Data set annotation used to specify which DbUnit dataset(s) should be loaded
before executing a test.
An interceptor that can specify the
"datatypeFactory" property of DbUnit.An interceptor that can enable/disable the
"datatypeWarning" feature of DbUnit.A simple and easy-to-use integration between DbUnit and spring
EmbeddedDatabase.This rule provide a fine integration between spring embedded database
and dbunit:
Ensure that embedded database is started and available before dbUnit load dataSet.
Shutdown database after test.
DbUnit exception.
A simple JUnit Jupiter extension for DbUnit.
An interceptor that can set the
"fetchSize" property of DbUnit.DbUnit initialization: allow user to run SQL scripts before
loading DbUnit data set.
Implementation of JUnit
Runner to fill and clear
database between each tests.DbUnit liquibase integration: allow test to initialize database with
liquibase and load DbUnit data set next.
An interceptor that can set the
"metadataHandler" property of DbUnit.Set of
DatabaseOperation supported out of the box.An interceptor that can enable/disable the
"qualifiedTableNames" feature of DbUnit.Annotation that define the list of
Replacements to use during
test suite.JUnit Rule to setup DbUnit database for each tests.
Generic class to run DbUnit before/after test method invocation.
Database operation to execute before test is executed.
A meta-annotation to automatically integrate Spring with DbUnit.
Database operation to execute after test is executed.
Specify DBUnit test using:
All dataset files located in:
/dataset
Default setup operation: DbUnitOperation.CLEAN_INSERT.
Default teardown operation: DbUnitOperation.TRUNCATE_TABLE.
Default value replacers (NullValueReplacementsProvider, NowValueReplacementsProvider, CurrentTimestampValueReplacementsProvider and CurrentTimeValueReplacementsProvider).
Spring test execution listener running DbUnit data set before and after test methods:
Get
DataSource bean from ApplicationContext.
Load data set, retrieved using DbUnitDataSet annotation.
Run setup operation before test method execution.
Run tear down operation after test method method execution..
Directory dataSet.
Builder for
DirectoryDataSet instances.Specify configuration for spring
EmbeddedDatabase.A JUnit Jupiter extension that can be used to start/stop an embedded database.
A JUnit 4
Rule that can be used to start/stop embedded database.A standalone runner that can be used to start/stop embedded database.
Static Exception Utilities.
Exception thrown when a field cannot be accessed.
Static Files Utilities.
Implementation of
JdbcForeignKeyManager for H2 DBMS.Implementation of
JdbcForeignKeyManager for HSQLDB DBMS.Implementation of
JdbcForeignKeyManager for database implementing the standard INFORMATION_SCHEMA system
used to introspect database.Static IO Utilities.
JDBC Configuration, defined by:
URL Connection.
User.
Password.
Factory that should create instance of
Connection.Wrap external SQL exception.
A foreign key manager is a (stateful) manager that can be used to
Disable foreign keys.
Re-enable foreign keys.
Note that disabling/enabling foreign keys should always be executed in the following order:
First, foreign key constraints are disabled, ie {
JdbcForeignKeyManager.disable(Connection) is called.
First, foreign key constraints are re-enabled, ie {JdbcForeignKeyManager.enable(Connection) is called.
Executing `enable` before `disable` (i.e in the wrong order) does not give any guarantee.Static JDBC Utilities, should only be used internally.
Implementation of
IDataSet with JSON file as input.Builder for
JsonDataSet instances.DatasetParser implementation that parses datasets from JSON input.Wrap external JSON parsing exception.
Parse JSON input and return
Map.Contract for JSON serializers that convert Java objects into
their JSON string representation.
Factory used to create default
JsonParser and JsonSerializer
implementations.Run liquibase change sets against SQL connection.
Exception thrown if an error occurred during the liquibase update operation.
Logger contract.
A logger provider, used to create loggers based on a given logger name.
Logger factory.
Implementation of
JdbcForeignKeyManager for MariaDB DBMS.Implementation of
JdbcForeignKeyManager for Microsoft SQL DBMS.Extension of
MySqlDataTypeFactory where BIT MySQL type
are handled as DataType.BIT instead of DataType.TINYINT.Implementation of
JdbcForeignKeyManager for MySQL DBMS.A
ReplacementsProvider that will map following valuesto the current date (i.e new Date()):
NOW()
now()
Static Objects Utilities.
Implementation of
JdbcForeignKeyManager for Oracle DBMS.Implementation of
JdbcForeignKeyManager for Postgres DBMS.Extended
PostgresqlDataTypeFactory that provides custom handling for
PostgreSQL string-like types such as json, jsonb, and varchar.Static PreConditions Utilities.
Visitor executed when a stream is read line by line.
Internal reflection utilities used by the dbUnit extension.
Replacement Objects.
Builder used to create new replacements objects.
Replacements provider, used to create re-usable replacements objects.
Error thrown when an error occurred when dealing with resources.
Implementations of strategies to load resources.
Error thrown when resource is not found.
Error thrown when resource is not a valid resource.
Functional interface used to map
ResultSet to another data structure.Internal helper utilities around Java's
ServiceLoader mechanism.Exception thrown if an error occurred during SQL parsing.
Run SQL scripts against SQL
Connection.Configuration for SQL scripts parser.
Builder for
SqlScriptParserConfiguration.Static Strings Utilities.
Utility class to implement easily
toString methods.Provide integration between spring
TransactionalTestExecutionListener and
custom DbUnitTestExecutionListener:
TransactionalTestExecutionListener will be executed first.
DbUnitTestExecutionListener will be executed last.
Implementation of
IDataSet with YAML file as input.Builder for
YamlDataSet instances.DatasetParser implementation that parses datasets from YAML input.Wrap external YAML parsing exception.
Read YAML inputs and return
Map object.Factory used to create the default
YamlParser implementation.