Class ToStringBuilder
java.lang.Object
com.github.mjeanroy.dbunit.commons.lang.ToStringBuilder
Utility class to implement easily
toString methods.
This class is part of internal API and should not be used publicly as it may changed at anytime.
-
Method Summary
Modifier and TypeMethodDescriptionAppend new char field.Append new object field.Append new string field.build()Create the final string.static ToStringBuilderCreate the builder with given class (the simple name will be used to start thetoStringvalue).static ToStringBuilderCreate the builder with given class of instance (the simple name will be used to start thetoStringvalue).
-
Method Details
-
create
Create the builder with given class (the simple name will be used to start thetoStringvalue).- Parameters:
klass- The class.- Returns:
- The builder.
-
create
Create the builder with given class of instance (the simple name will be used to start thetoStringvalue).- Parameters:
instance- The instance.- Returns:
- The builder.
-
append
Append new string field.- Parameters:
name- Field name.value- Field value.- Returns:
- The builder.
-
append
Append new char field.- Parameters:
name- Field name.value- Field value.- Returns:
- The builder.
-
append
Append new object field.- Parameters:
name- Field name.object- Field value.- Returns:
- The builder.
-
build
-