Annotation Type DbUnitConnection
Set the DBUnit connection configuration.
-
Required Element Summary
Required Elements -
Optional Element Summary
Optional Elements
-
Element Details
-
driver
String driverDatabase driver to use: default is the empty string and the driver will automatically be selected, based on the connection URL.- Returns:
- Database driver.
- Default:
""
-
url
-
user
-
password
-