Annotation Type DbUnitReplacements
Annotation that define the list of
Replacements to use during
test suite. These replacements are created by given providers() (note that these providers must have an
empty public constructor).-
Required Element Summary
Required ElementsModifier and TypeRequired ElementDescriptionClass<? extends ReplacementsProvider>[]The list of providers to use. -
Optional Element Summary
Optional ElementsModifier and TypeOptional ElementDescriptionbooleanA flag indicating if given annotation should be merged with "parent" annotations.
-
Element Details
-
providers
Class<? extends ReplacementsProvider>[] providersThe list of providers to use.- Returns:
- List of providers.
-
inherit
boolean inheritA flag indicating if given annotation should be merged with "parent" annotations. For example, a method can define additional replacements providers to load. The default value isfalse, this means that the providers for the annotated class will shadow and effectively replace any datasets defined by superclasses. Iftrue, this means that an annotated class will inherit the datasets defined by test superclasses (or meta-annotations).- Returns:
- The inherit flag value.
- Default:
false
-